@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """
@@ -283,7 +283,7 @@ class Settings:
                 msg += type + ":" + name + ":" + str(score) + ":" + str(level)
                 msg += "\n"
         if self.outfd is not None:
-            write(self.outfd, msg + "\n")
+            write(self.outfd, (msg + "\n").encode())
         else:
             try:
                 file = open(self.scorefile, "w")
@@ -454,8 +454,8 @@ class System:
         (x, y) = coords
         self.background.blit(surf, (int(x), int(y)))
 
-    def blit_board(self, xxx_todo_changeme):
-        (x1, y1, x2, y2) = xxx_todo_changeme
+    def blit_board(self, coords):
+        (x1, y1, x2, y2) = coords
         x1, y1 = x1 * ITEM_SIZE, y1 * ITEM_SIZE
         x2, y2 = x2 * ITEM_SIZE - x1, y2 * ITEM_SIZE - y1
         surf = data.board.subsurface((x1, y1, x2, y2))
@@ -863,8 +863,8 @@ class Game:
         if self.select:
             system.blit(data.selector, select_coord)
 
-    def piece_draw(self, sprite, xxx_todo_changeme1):
-        (x, y) = xxx_todo_changeme1
+    def piece_draw(self, sprite, pos):
+        (x, y) = pos
         width = ITEM_SIZE
         crop = sprite.subsurface
         # Constrain X
@@ -1474,6 +1474,31 @@ class Monsterz:
                 return True
         return False
 
+    wander_monster = randint(0, ITEMS-1)
+    wander_x = None
+    wander_y = 0
+
+    def wanderer_draw(self):
+        if self.wander_x == None:
+            if randint(0, 30) == 1:
+                self.wander_monster = (self.wander_monster+1) % ITEMS
+                self.wander_y = randint(20, SCREEN_HEIGHT-ITEM_SIZE-20)
+                self.wander_x = -ITEM_SIZE
+            return
+        if randint(0, 10) == 1:
+            monster = data.blink[self.wander_monster]
+        else:
+            monster = data.normal[self.wander_monster]
+        system.blit(monster, (self.wander_x, self.wander_y))
+        if self.wander_x < SCREEN_WIDTH/3 or self.wander_x > (SCREEN_WIDTH/3)*2:
+            self.wander_x += randint(4, 8)
+            self.wander_y += randint(-2, 2)
+        else:
+            self.wander_x += 3
+            self.wander_y += randint(-1, 1)
+        if self.wander_x > SCREEN_WIDTH:
+            self.wander_x = None
+
     msat = [0] * 4
     marea = None
 
@@ -1504,6 +1529,7 @@ class Monsterz:
         # Print logo and menu
         w, h = data.logo.get_size()
         system.blit(data.logo, (24 + 192 - w // 2, 24 + 96 - h // 2))
+        self.wanderer_draw()
         for x in range(4):
             if self.msat[x] > 180:
                 monster = data.surprise[shapes[x]]
@@ -1624,7 +1650,7 @@ class Monsterz:
                 system.play("whip")
                 self.status = STATUS_MENU
                 return
-            elif event.type == pygame.MOUSEBUTTONDOWN and narea >= 10:
+            elif event.type == pygame.MOUSEBUTTONDOWN and narea is not None and narea >= 10:
                 system.play("whip")
                 if narea == ACTION_MOREMONSTERZ:
                     if items < 8:
@@ -2050,16 +2076,16 @@ def usage():
     print("Usage: monsterz [OPTION]...")
     print()
     print("Options")
+    print("     --data <dir>   set alternate data directory to <dir>")
     print(" -f, --fullscreen   start in full screen mode")
     print(" -h, --help         display this help and exit")
     print(" -m, --nomusic      disable music")
-    print(" -s, --nosfx        disable sound effects")
     print("     --outfd <fd>   output scores to file descriptor <fd>")
-    print("     --data <dir>   set alternate data directory to <dir>")
+    print(" -s, --nosfx        disable sound effects")
     print("     --score <file> set score file to <file>")
     print(" -v, --version      display version information and exit")
     print()
-    print("Report bugs or suggestions to <sam@zoy.org>.")
+    print("Report bugs or suggestions at https://github.com/0-wiz-0/monsterz/issues")
 
 
 def main():
@@ -2101,7 +2127,7 @@ def main():
         elif opt in ("--outfd"):
             try:
                 outfd = int(arg)
-                write(outfd, "\n")
+                write(outfd, b"\n")
             except:
                 outfd = None
         elif opt in ("--data"):
